@@ -1,22 +1,22 @@
 #' Animate a tour path.
 #'
 #' This is the function that powers all of the tour animations.  If you want
-#' to write your own tour animation method, the best place to 
-#' start is by looking at the code for animation methods that have already 
+#' to write your own tour animation method, the best place to
+#' start is by looking at the code for animation methods that have already
 #' implemented in the package.
 #'
 #' See \code{\link{render}} to render animations to disk.
 #'
 #' @param data matrix, or data frame containing numeric columns
 #' @param tour_path tour path generator, defaults to 2d grand tour
-#' @param start projection to start at, if not specified, uses default 
+#' @param start projection to start at, if not specified, uses default
 #'   associated with tour path
 #' @param display takes the display that is suppose to be used, defaults to
 #'   the xy display
 #' @param aps target angular velocity (in radians per second)
 #' @param fps target frames per second (defaults to 30)
 #' @param max_frames the maximum number of bases to generate.  Defaults to
-#'   Inf for interactive use (must use Ctrl + C to terminate), and 1 for 
+#'   Inf for interactive use (must use Ctrl + C to terminate), and 1 for
 #'   non-interactive use.
 #' @param rescale if true, rescale all variables to range [0,1]?
 #' @param sphere if true, sphere all variables
@@ -24,21 +24,21 @@
 #' @return an (invisible) list of bases visited during this tour
 #' @references Hadley Wickham, Dianne Cook, Heike Hofmann, Andreas Buja
 #'   (2011). tourr: An R Package for Exploring Multivariate Data with
-#'   Projections. Journal of Statistical Software, 40(2), 1-18. 
+#'   Projections. Journal of Statistical Software, 40(2), 1-18.
 #'   \url{http://www.jstatsoft.org/v40/i02/}.
 #' @export
-#' @examples 
+#' @examples
 #' f <- flea[, 1:6]
 #' animate(f, grand_tour(), display_xy())
 #' # or in short
 #' animate(f)
 #' animate(f, max_frames = 30)
-#' 
+#'
 #' \dontrun{animate(f, max_frames = 10, fps = 1, aps = 0.1)}
 animate <- function(data, tour_path = grand_tour(), display = display_xy(), start = NULL, aps = 1, fps = 30, max_frames = Inf, rescale = TRUE, sphere = FALSE, ...) {
   if (rescale) data <- rescale(data)
   if (sphere) data  <- sphere(data)
-  
+
   # By default, only take single step if not interactive
   # This is useful for the automated tests run by R CMD check
   if (!interactive() && missing(max_frames)) {
@@ -47,6 +47,11 @@ animate <- function(data, tour_path = grand_tour(), display = display_xy(), star
   if (max_frames == Inf) {
     to_stop()
   }
+  plat <- find_platform()
+  if (rstudio_gd() && fps > 19) {
+    warning("Rstudio graphics device supports maximum fps of 19", call. = FALSE)
+    fps <- 19
+  }
 
   tour <- new_tour(data, tour_path, start)
   start <- tour(0)
@@ -56,12 +61,11 @@ animate <- function(data, tour_path = grand_tour(), display = display_xy(), star
   # Initialise display
   display$init(data)
   display$render_frame()
-  display$render_data(data, start$proj, start$target)
-  os <- find_platform()$os
-  
+  display$render_data(data, start$proj)
+
   b <- 0
   i <- 0
-  
+
   tryCatch({
     while(i < max_frames) {
       i <- i + 1
@@ -76,25 +80,25 @@ animate <- function(data, tour_path = grand_tour(), display = display_xy(), star
         }
         bases[, , b] <- step$target
       }
-      
+
       dev.hold()
       on.exit(dev.flush())
-      if (os == "win") {
+      if (plat$os == "win" || plat$iface == "rstudio") {
         display$render_frame()
       } else {
         display$render_transition()
       }
       display$render_data(data, step$proj, step$target)
       dev.flush()
-    
-      Sys.sleep(1 / fps)    
+
+      Sys.sleep(1 / fps)
     }
   }, interrupt = function(cond) {
     dev.flush()
     return()
   })
-  
+
   invisible(bases[, , seq_len(b)])
 }
 
-
+rstudio_gd <- function() identical(names(dev.cur()), "RStudioGD")
